@@ -5,7 +5,10 @@ from mongoengine import dereference
 from mongoengine.base.document import BaseDocument
 from mongoengine.document import Document
 from rest_framework import serializers
-
+import sys
+if sys.version_info[0] >= 3:
+    def unicode(val):
+        return str(val)
 
 class MongoDocumentField(serializers.WritableField):
     MAX_RECURSION_DEPTH = 5  # default value of depth
@@ -111,10 +114,11 @@ class EmbeddedDocumentField(MongoDocumentField):
     def get_default_value(self):
         return self.to_native(self.default())
 
+    def to_native(self, obj):
+        return self.model_field.to_mongo(obj).to_dict()
+
     def from_native(self, obj):
-        if not obj:
-            return self.get_default_value()
-        return self.document_type(**obj)
+        return self.model_field.to_python(obj)
 
 
 class DynamicField(MongoDocumentField):
@@ -122,4 +126,4 @@ class DynamicField(MongoDocumentField):
     type_label = 'DynamicField'
 
     def to_native(self, obj):
-        return self.transform_object(obj, self.MAX_RECURSION_DEPTH)
\ No newline at end of file
+        return self.transform_object(obj, self.depth)
